@@ -7,6 +7,7 @@ Vaico
 import zipimport
 import pickle
 import logging
+import zipfile
 from sys import path as sys_path
 from os.path import join
 
@@ -23,14 +24,23 @@ def load_zip_model(model_path, zip_path):
     log.info('Loading model from: {}'.format(model_path))
     with open(model_path, 'rb') as handle:
         model_data = pickle.load(handle)
-    arch_name = model_data['conf']['architecture']
+    target_name = model_data['conf']['architecture']
 
     log.info('Loading architecture module: {}'.format(zip_path))
     sys_path.append(join(zip_path, 'python'))
 
     importer = zipimport.zipimporter(zip_path)
-    #'python/{0}/{0}'.format(arch_name.lower())
-    model_module = importer.load_module(join('python', arch_name.lower(), arch_name.lower()))
+    # Get architecture folder and module names
+    arch_name = None
+    module_name = None
+    with zipfile.ZipFile(zip_path, 'r') as zf:
+        for name in zf.namelist():
+            if 'python/{0}/{0}'.format(target_name).lower() in name.lower():
+                _, arch_name, module_name = name.split('/')
+                module_name = module_name.split('.')[0]
+    log.info('Loading: {}/{}'.format(arch_name, module_name))
+
+    model_module = importer.load_module(join('python', arch_name, module_name))
 
     # Search architecture class name in module
     for attr in dir(model_module):
